==> autoprofile_2.10.orig.tar.gz: autoprofile-2.10/src/comp_rss.h <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"

struct rss_entry {
  struct tm *t;
  char *title;
  char *entry;
  char *url;
};

typedef enum
{
  RSS_UNKNOWN = 0,
  RSS_XANGA,
  RSS_LIVEJOURNAL,
  RSS_2
} RSS_TYPE;

GList *parse_rss (void);

==> autoprofile_2.14.orig.tar.gz: autoprofile-2.14/src/comp_rss.h <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"
#include "time.h"

#define MAX_USERNAME_LENGTH 1000

struct rss_entry {
  struct tm *t;
  char *title;
  char *entry;
  char *url;
  char *comments;
};

typedef enum
{
  RSS_UNKNOWN = -1,
  RSS_XANGA,
  RSS_LIVEJOURNAL,
  RSS_2
} RSS_TYPE;

extern GList *entries;

void parse_rss (void);
void parse_xanga_rss (gchar *);
GMarkupParser rss_parser;
